==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lximage-qt/lximage-qt_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>LxImage::Application</name>
    <message>
        <location filename="../../application.cpp" line="89"/>
        <source>Take a screenshot</source>
        <translation>Pren una captura de pantalla</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="93"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[FITXER1, FITXER2,...]</translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <location filename="../../mainwindow.cpp" line="148"/>
        <source>About</source>
        <translation>Quant a</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="149"/>
        <source>LXImage - a simple and fast image viewer

Copyright (C) 2013
LXDE Project: http://lxde.org/

Authors:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>LXImage - un visualitzador d&apos;imatges senzill i ràpid

Copyright (C) 2013
Projecte LXDE: http://lxde.org/

Autors:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="242"/>
        <source>Open File</source>
        <translation>Obre un fitxer</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="243"/>
        <location filename="../../mainwindow.cpp" line="264"/>
        <source>Image files (%1)</source>
        <translation>Fitxers d&apos;imatges (%1)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="264"/>
        <source>Save File</source>
        <translation>Desa el fitxer</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="530"/>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation>[*]%1 (s&apos;està carregant...) - Visualitzador d&apos;imatges</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="535"/>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation>[*]%1 (ha fallat la càrrega) - Visualitzador d&apos;imatges</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="539"/>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation>[*]%1 (%2x%3) - Visualitzador d&apos;imatges</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="576"/>
        <source>[*]Image Viewer</source>
        <translation>[*]Visualitzador d&apos;imatges</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="819"/>
        <source>Thumbnails</source>
        <translation>Miniatures</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../mainwindow.ui" line="14"/>
        <source>Image Viewer</source>
        <translation>Visualitzador d&apos;imatges</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="159"/>
        <source>&amp;About</source>
        <translation>Qu&amp;ant a</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="169"/>
        <source>&amp;Open File</source>
        <translation>&amp;Obre un fitxer</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="172"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="182"/>
        <source>&amp;Save</source>
        <translation>De&amp;sa</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="185"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="195"/>
        <source>Save &amp;As</source>
        <translation>&amp;Anomena i desa</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="198"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="208"/>
        <source>&amp;Close</source>
        <translation>Tan&amp;ca</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="211"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="221"/>
        <source>Zoom &amp;In</source>
        <translation>Ampl&amp;ia el zoom</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="224"/>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="234"/>
        <source>Zoom &amp;Out</source>
        <translation>Redueix el z&amp;oom</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="237"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="247"/>
        <source>&amp;Copy to Clipboard</source>
        <translation>&amp;Copia al porta-retalls</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="257"/>
        <location filename="../../mainwindow.ui" line="260"/>
        <source>Next File</source>
        <translation>Fitxer següent</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="273"/>
        <location filename="../../mainwindow.ui" line="276"/>
        <source>Previous File</source>
        <translation>Fitxer anterior</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="263"/>
        <source>PgDown</source>
        <translation>Re Pàg</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="279"/>
        <source>PgUp</source>
        <translation>Av Pàg</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="289"/>
        <source>Original Size</source>
        <translation>Mida original</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="299"/>
        <source>&amp;Fit</source>
        <translation>A&amp;justa</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="309"/>
        <source>&amp;Rotate Clockwise</source>
        <translation>Gi&amp;ra en sentit horari</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="319"/>
        <source>Rotate &amp;Counterclockwise</source>
        <translation>Gira en sentit anti&amp;horari</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="324"/>
        <source>P&amp;references</source>
        <translation>P&amp;referències</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="329"/>
        <source>&amp;Print</source>
        <translation>Im&amp;primeix</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="332"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="342"/>
        <source>First File</source>
        <translation>Primer fitxer</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="345"/>
        <source>Home</source>
        <translation>Inici</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="355"/>
        <source>Last File</source>
        <translation>Últim fitxer</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="358"/>
        <source>End</source>
        <translation>Fi</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="368"/>
        <source>&amp;New Window</source>
        <translation>Finestra &amp;nova</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="371"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="376"/>
        <source>Flip &amp;Horizontally</source>
        <translation>Inverteix &amp;horitzontalment</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="386"/>
        <source>Capture Screenshot</source>
        <translation>Pren una captura de pantalla</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="394"/>
        <source>F&amp;ull Screen</source>
        <translation>Pantalla c&amp;ompleta</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="397"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="402"/>
        <source>Flip &amp;Vertically</source>
        <translation>Inverteix &amp;verticalment</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="412"/>
        <source>&amp;Paste from Clipboard</source>
        <translation>Enganxa del &amp;porta-retalls</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="425"/>
        <source>&amp;Slide Show</source>
        <translation>Presentació de diapo&amp;sitives</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="435"/>
        <source>&amp;Delete</source>
        <translation>&amp;Suprimeix</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="438"/>
        <source>Del</source>
        <translation>Supr</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="446"/>
        <source>Show Thumbnails</source>
        <translation>Mostra les miniatures</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="451"/>
        <source>File Properties</source>
        <translation>Propietats del fitxer</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="55"/>
        <source>&amp;File</source>
        <translation>&amp;Fitxer</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="71"/>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="77"/>
        <source>Go</source>
        <translation>Vés</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="86"/>
        <source>&amp;View</source>
        <translation>&amp;Vista</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="100"/>
        <source>&amp;Edit</source>
        <translation>&amp;Edita</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="120"/>
        <source>Toolbar</source>
        <translation>Barra d&apos;eines</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../../preferencesdialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>Preferències</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="33"/>
        <source>Icon theme:</source>
        <translation>Tema de les icones:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="43"/>
        <source>Normal background color:</source>
        <translation>Color del fons normal:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="50"/>
        <source>Fullscreen background color:</source>
        <translation>Color del fons pantalla completa:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="71"/>
        <source>Slide show interval (seconds):</source>
        <translation>Interval per mostrar la diapositiva (segons):</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="24"/>
        <source>General</source>
        <translation>General</translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <location filename="../../screenshotdialog.ui" line="14"/>
        <source>Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="28"/>
        <source>Take a screenshot</source>
        <translation>Pren una captura de pantalla</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="35"/>
        <source>Region</source>
        <translation>Regió</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="41"/>
        <source>Whole screen</source>
        <translation>Tota la pantalla</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="51"/>
        <source>Current window only</source>
        <translation>Tan sols la finestra activa</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="61"/>
        <source>Include mouse cursor</source>
        <translation>Inclou el cursor del ratolí</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="68"/>
        <source> seconds</source>
        <translation> segons</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="85"/>
        <source>Delay:</source>
        <translation>Retard:</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="95"/>
        <source>Include window title and frame</source>
        <translation>Inclou el títol de la finestra i el marc</translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/lximage-qt/lximage-qt_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>LxImage::Application</name>
    <message>
        <location filename="../../application.cpp" line="94"/>
        <source>Take a screenshot</source>
        <translation>Pren una captura de pantalla</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="98"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[FITXER1, FITXER2,...]</translation>
    </message>
</context>
<context>
    <name>LxImage::ImageShackUpload</name>
    <message>
        <location filename="../../upload/imageshackupload.cpp" line="49"/>
        <source>unknown error response</source>
        <translation>resposta d&apos;error desconeguda</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgurUpload</name>
    <message>
        <location filename="../../upload/imgurupload.cpp" line="46"/>
        <source>unknown error response</source>
        <translation>resposta d&apos;error desconeguda</translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <location filename="../../mainwindow.cpp" line="145"/>
        <source>About</source>
        <translation>Quant a</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="146"/>
        <source>LXImage - a simple and fast image viewer

Copyright (C) 2013
LXQt Project: https://lxqt.org/

Authors:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>LXImage - un visualitzador d&apos;imatges senzill i ràpid

Copyright (C) 2013
Projecte LXQt: https://lxqt.org/

Autors:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="255"/>
        <source>Open File</source>
        <translation>Obre un fitxer</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="256"/>
        <location filename="../../mainwindow.cpp" line="283"/>
        <source>Image files (%1)</source>
        <translation>Fitxers d&apos;imatges (%1)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="262"/>
        <source>Open directory</source>
        <translation>Obre un directori</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="283"/>
        <source>Save File</source>
        <translation>Desa el fitxer</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="539"/>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation>[*]%1 (s&apos;està carregant...) - Visualitzador d&apos;imatges</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="544"/>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation>[*]%1 (ha fallat la càrrega) - Visualitzador d&apos;imatges</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="548"/>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation>[*]%1 (%2x%3) - Visualitzador d&apos;imatges</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="584"/>
        <source>[*]Image Viewer</source>
        <translation>[*]Visualitzador d&apos;imatges</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="851"/>
        <source>Thumbnails</source>
        <translation>Miniatures</translation>
    </message>
</context>
<context>
    <name>LxImage::UploadDialog</name>
    <message>
        <location filename="../../upload/uploaddialog.cpp" line="47"/>
        <source>Imgur</source>
        <translation>Imgur</translation>
    </message>
    <message>
        <location filename="../../upload/uploaddialog.cpp" line="48"/>
        <source>ImageShack</source>
        <translation>ImageShack</translation>
    </message>
    <message>
        <location filename="../../upload/uploaddialog.cpp" line="124"/>
        <source>Start</source>
        <translation>Inicia</translation>
    </message>
    <message>
        <location filename="../../upload/uploaddialog.cpp" line="127"/>
        <source>Stop</source>
        <translation>Atura</translation>
    </message>
    <message>
        <location filename="../../upload/uploaddialog.cpp" line="130"/>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
    <message>
        <location filename="../../upload/uploaddialog.cpp" line="137"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../mainwindow.ui" line="14"/>
        <source>Image Viewer</source>
        <translation>Visualitzador d&apos;imatges</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="162"/>
        <source>&amp;About</source>
        <translation>Qu&amp;ant a</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="172"/>
        <source>&amp;Open File</source>
        <translation>&amp;Obre un fitxer</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="175"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="185"/>
        <source>&amp;Save</source>
        <translation>De&amp;sa</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="188"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="198"/>
        <source>Save &amp;As</source>
        <translation>&amp;Anomena i desa</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="201"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="211"/>
        <source>&amp;Close</source>
        <translation>Tan&amp;ca</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="214"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="224"/>
        <source>Zoom &amp;In</source>
        <translation>Ampl&amp;ia el zoom</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation type="vanished">Ctrl++</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="237"/>
        <source>Zoom &amp;Out</source>
        <translation>Redueix el z&amp;oom</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="240"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="250"/>
        <source>&amp;Copy to Clipboard</source>
        <translation>&amp;Copia al porta-retalls</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="260"/>
        <location filename="../../mainwindow.ui" line="263"/>
        <source>Next File</source>
        <translation>Fitxer següent</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="276"/>
        <location filename="../../mainwindow.ui" line="279"/>
        <source>Previous File</source>
        <translation>Fitxer anterior</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="266"/>
        <source>PgDown</source>
        <translation>Re Pàg</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="227"/>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="282"/>
        <source>PgUp</source>
        <translation>Re Pàg</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="292"/>
        <source>Original Size</source>
        <translation>Mida original</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="295"/>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="305"/>
        <source>&amp;Fit</source>
        <translation>A&amp;justa</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="315"/>
        <source>&amp;Rotate Clockwise</source>
        <translation>Gi&amp;ra en sentit horari</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="325"/>
        <source>Rotate &amp;Counterclockwise</source>
        <translation>Gira en sentit anti&amp;horari</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="330"/>
        <source>P&amp;references</source>
        <translation>P&amp;referències</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="335"/>
        <source>&amp;Print</source>
        <translation>Im&amp;primeix</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="338"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="348"/>
        <source>First File</source>
        <translation>Primer fitxer</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="351"/>
        <source>Home</source>
        <translation>Inici</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="361"/>
        <source>Last File</source>
        <translation>Últim fitxer</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="364"/>
        <source>End</source>
        <translation>Fi</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="374"/>
        <source>&amp;New Window</source>
        <translation>Finestra &amp;nova</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="377"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="382"/>
        <source>Flip &amp;Horizontally</source>
        <translation>Inverteix &amp;horitzontalment</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="392"/>
        <source>Capture Screenshot</source>
        <translation>Pren una captura de pantalla</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="400"/>
        <source>F&amp;ull Screen</source>
        <translation>Pantalla c&amp;ompleta</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="403"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="408"/>
        <source>Flip &amp;Vertically</source>
        <translation>Inverteix &amp;verticalment</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="418"/>
        <source>&amp;Paste from Clipboard</source>
        <translation>Enganxa del &amp;porta-retalls</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="431"/>
        <source>&amp;Slide Show</source>
        <translation>Presentació de diapo&amp;sitives</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="441"/>
        <source>&amp;Delete</source>
        <translation>&amp;Suprimeix</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="444"/>
        <source>Del</source>
        <translation>Supr</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="452"/>
        <source>Show Thumbnails</source>
        <translation>Mostra les miniatures</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="457"/>
        <source>File Properties</source>
        <translation>Propietats del fitxer</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="465"/>
        <source>Open &amp;Directory</source>
        <translation>Obre un &amp;directori</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="468"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="476"/>
        <source>Upload</source>
        <translation>Puja</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="479"/>
        <source>Upload the image</source>
        <translation>Puja la imatge</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="55"/>
        <source>&amp;File</source>
        <translation>&amp;Fitxer</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="72"/>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="78"/>
        <source>Go</source>
        <translation>Vés</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="87"/>
        <source>&amp;View</source>
        <translation>&amp;Vista</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="101"/>
        <source>&amp;Edit</source>
        <translation>&amp;Edita</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="123"/>
        <source>Toolbar</source>
        <translation>Barra d&apos;eines</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../../preferencesdialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>Preferències</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="33"/>
        <source>Icon theme:</source>
        <translation>Tema de les icones:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="43"/>
        <source>Normal background color:</source>
        <translation>Color del fons normal:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="50"/>
        <source>Fullscreen background color:</source>
        <translation>Color del fons pantalla completa:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="71"/>
        <source>Slide show interval (seconds):</source>
        <translation>Interval per mostrar la diapositiva (segons):</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="24"/>
        <source>General</source>
        <translation>General</translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <location filename="../../screenshotdialog.ui" line="14"/>
        <source>Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="27"/>
        <source>Take a screenshot</source>
        <translation>Pren una captura de pantalla</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="34"/>
        <source>Region</source>
        <translation>Regió</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="40"/>
        <source>Whole screen</source>
        <translation>Tota la pantalla</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="50"/>
        <source>Current window only</source>
        <translation>Tan sols la finestra activa</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="57"/>
        <source>Capture an area of the screen</source>
        <translation>Captura una àrea de la pantalla</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="67"/>
        <source>Include mouse cursor</source>
        <translation>Inclou el cursor del ratolí</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="74"/>
        <source> seconds</source>
        <translation> segons</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="91"/>
        <source>Delay:</source>
        <translation>Retard:</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="101"/>
        <source>Include window title and frame</source>
        <translation>Inclou el títol de la finestra i el marc</translation>
    </message>
</context>
<context>
    <name>UploadDialog</name>
    <message>
        <location filename="../../upload/uploaddialog.ui" line="14"/>
        <source>Upload</source>
        <translation>Puja</translation>
    </message>
</context>
</TS>
